## see: http://blogs.msdn.com/b/powershell/archive/2006/10/16/windows-powershell-font-customization.aspx

$key = "HKLM:\SOFTWARE\Microsoft\Windows NT\CurrentVersion\Console\TrueTypeFont"

## Find out if C64 Pro is installed on the system
if(!(test-path (join-path $env:windir "Fonts\C64_Pro_Mono-STYLE.TTF"))) {
	write-host "C64 Pro Mono is not installed on the system."
	break
}

## Report currently enabled cmd/powershell fonts
$installed_all = get-itemproperty $key | get-member | where-object { $_.Name -match "^0+$" }
if($installed_all -ne $null) {
        write-host "Currently enabled: " $installed_all
}

## Determine if C64 Pro is already enabled as a cmd/powershell font
$installed = get-itemproperty $key |  get-member | where-object { $_.Name -match "^0+$" } | where-object { $_.Definition -match "C64 Pro Mono" }
if($installed -ne $null) {
        write-host "The C64 Pro Mono font is already installed as a cmd/powershell font."
        break
}

## Find out what the largest string of zeros is
$zeros = (get-itemproperty $key | get-member | where-object { $_.Name -match "^0+$" } | measure-object).Count

## Install the font
new-itemproperty $key -Name ("0" * ($zeros + 1)) -Type string -Value "C64 Pro Mono"
write-host "C64 Pro Mono font installed successfully as a cmd/powershell font."

